CrossmintLogger class abstract interface

Implementers

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

debug(String message, [Map<String, Object?> fields = const {}]) → void
error(String message, [Map<String, Object?> fields = const {}, Object? error]) → void
info(String message, [Map<String, Object?> fields = const {}]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
warn(String message, [Map<String, Object?> fields = const {}]) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited