CrossmintApiServiceBase class abstract base

Constructors

CrossmintApiServiceBase({required CrossmintTransport transport, required CrossmintJwtProvider jwtProvider, required CrossmintLogger logger})

Properties

hashCode int
The hash code for this object.
no setterinherited
logger CrossmintLogger
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
transport CrossmintTransport
final

Methods

expectSuccessfulBody(CrossmintTransportResponse response, CrossmintExceptionFactory exceptionFactory, {required String operation}) Object?
expectSuccessfulMap(CrossmintTransportResponse response, CrossmintExceptionFactory exceptionFactory, {required String operation}) CrossmintJsonMap
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
request({CrossmintJsonMap queryParameters = const <String, Object?>{}, Object? body, Map<String, String> headers = const <String, String>{}, bool includeApiKey = true, String? methodOverride}) CrossmintRequestOptions
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited